|
||||||||||
| PREV NEXT | FRAMES NO FRAMES | |||||||||
AreaCodeMap.
PhoneNumberMatches in text.
PhoneNumberMatches in text.
PhoneNumberUtil.format(Phonenumber.PhoneNumber, PhoneNumberUtil.PhoneNumberFormat), but
accepts a mutable StringBuilder as a parameter to decrease object creation when invoked many
times.
carrierCode.
AsYouTypeFormatter for the specific region.
PhoneNumberOfflineGeocoder instance to carry out international phone number
geocoding.
PhoneNumberUtil instance to carry out international phone number formatting,
parsing, or validation.
nationalNumber_ field of the
PhoneNumber object passed in, so that clients could use it to split a national significant
number into geographical area code and subscriber number.
AsYouTypeFormatter.inputDigitAndRememberPosition(char).
AsYouTypeFormatter.inputDigit(char), but remembers the position where nextChar is inserted, so
that it can be retrieved later by using AsYouTypeFormatter.getRememberedPosition().
PhoneNumberUtil.isPossibleNumberWithReason(com.google.i18n.phonenumbers.Phonenumber.PhoneNumber).
MappingFileProvider.
PhoneNumberUtil.parse(String, String), but accepts mutable PhoneNumber as a parameter to
decrease object creation when invoked many times.
PhoneNumberUtil.parseAndKeepRawInput(String, String), but accepts a mutable PhoneNumber as
a parameter to decrease object creation when invoked many times.
AreaCodeMap initialized with sortedAreaCodeMap.
MappingFileProvider with availableDataFiles.
|
||||||||||
| PREV NEXT | FRAMES NO FRAMES | |||||||||